@@ -14,13 +14,14 @@ LAND_POLYGONS_PATH = os.path.join(
     USER_DL_DIR, 'land-polygons-split-4326', 'land_polygons.shp')
 GEOFABRIK_PATH = os.path.join(USER_DL_DIR, 'geofabrik.json')
 USER_OUTPUT_DIR = os.path.join(USER_WAHOO_MC, '_tiles')
+USER_CONFIG_DIR = os.path.join(USER_WAHOO_MC, '_config')
 
 # Python Package - wahooMapsCreator directory
 WAHOO_MC_DIR = os.path.dirname(__file__)
 RESOURCES_DIR = os.path.join(WAHOO_MC_DIR, 'resources')
 TOOLING_WIN_DIR = os.path.join(WAHOO_MC_DIR, 'tooling_win')
 ROOT_DIR = os.path.abspath(os.path.join(os.path.dirname(__file__), os.pardir))
-VERSION = '3.0.0'
+VERSION = '3.1.0'
 
 Translate_Country = {
     'alaska':                           'united_states_of_america',
@@ -31,6 +32,7 @@ Translate_Country = {
     'british_indian_ocean_territory':   'asia',
     'brunei':                           'malaysia-singapore-brunei',
     'burkina_faso':                     'burkina-faso',
+    'canary_islands':					'canary-islands',
     'cape_verde':                       'cape-verde',
     'christmas_island':                 'indonesia',
     'cocos_islands':                    'australia',
@@ -96,7 +98,7 @@ continents = ['europe', 'unitedstates', 'north-america', 'south-america', 'asia'
               'africa', 'antarctica']
 
 africa = ['algeria', 'angola', 'benin', 'botswana', 'burkina_faso', 'burundi',
-          'cameroon', 'cape_verde', 'central_african_republic', 'chad', 'comoros',
+          'cameroon', 'canary_islands', 'cape_verde', 'central_african_republic', 'chad', 'comoros',
           'cote_d_ivoire', 'democratic_republic_of_the_congo', 'djibouti', 'egypt',
           'equatorial_guinea', 'eritrea', 'ethiopia', 'french_southern_territories', 'gabon',
           'gambia', 'ghana', 'guinea-bissau', 'guinea', 'kenya', 'lesotho', 'liberia',
@@ -161,7 +163,7 @@ unitedstates = ['alabama', 'alaska', 'american_samoa', 'arizona', 'arkansas',
                 'vermont', 'virginia', 'washington', 'west_virginia', 'wisconsin', 'wyoming']
 
 africa_geofabrik = ['algeria', 'angola', 'benin', 'botswana', 'burkina-faso', 'burundi',
-                    'cameroon', 'Canary Islands', 'cape-verde', 'central african republic', 'chad',
+                    'cameroon', 'canary-islands', 'cape-verde', 'central african republic', 'chad',
                     'comores', 'Congo (Republic/Brazzaville)', 'congo-democratic-republic', 'djibouti',
                     'egypt', 'Equatorial Guinea', 'eritrea', 'ethiopia', 'gabon', 'ghana', 'guinea',
                     'guinea-bissau', 'ivory-coast', 'kenya', 'lesotho', 'liberia', 'libya', 'madagascar',
@@ -196,7 +198,7 @@ europe_geofabrik = ['albania', 'andorra', 'austria', 'azores', 'belarus', 'belgi
                     'isle-of-man', 'italy', 'kosovo', 'latvia', 'liechtenstein', 'lithuania', 'luxembourg',
                     'macedonia', 'malta', 'moldova', 'monaco', 'montenegro', 'netherlands', 'norway',
                     'poland', 'portugal', 'romania', 'russian federation', 'serbia', 'slovakia',
-                    'slovenia', 'spain', 'sweden', 'switzerland', 'turkey', 'ukraine (with crimea)']
+                    'slovenia', 'spain', 'sweden', 'switzerland', 'turkey', 'ukraine']
 
 northamerica_geofabrik = ['canada', 'greenland', 'mexico', 'us midwest', 'us northeast',
                           'us pacific', 'us south', 'us west']
@@ -243,32 +245,3 @@ block_download = ['dach', 'alps', 'britain-and-ireland', 'south-africa-and-lesot
 # Special_regions like (former) colonies where the map of the wanted region is not present in the map of the parent country.
 # example Guadeloupe, it's Geofabrik parent country is France but Guadeloupe is not located within the region covered by the map of France.
 special_regions = ['guadeloupe', 'guyane', 'martinique', 'mayotte', 'reunion']
-
-# Tags to keep
-TAGS_TO_KEEP_UNIVERSAL = {
-    'access': '',
-    'area': 'yes',
-    'bicycle': '',
-    'bridge': '',
-    'foot': ['ft_yes', 'foot_designated'],
-    'amenity': ['fuel', 'cafe', 'drinking_water'],
-    'shop': ['bakery', 'bicycle'],
-    'highway': ['abandoned', 'bus_guideway', 'disused', 'bridleway', 'byway', 'construction', 'cycleway', 'footway', 'living_street', 'motorway', 'motorway_link', 'path', 'pedestrian', 'primary', 'primary_link', 'residential', 'road', 'secondary', 'secondary_link', 'service', 'steps', 'tertiary', 'tertiary_link', 'track', 'trunk', 'trunk_link', 'unclassified'],
-    'natural': ['coastline', 'nosea', 'sea', 'beach', 'land', 'scrub', 'water', 'wetland', 'wood'],
-    'landuse': ['forest', 'commercial', 'industrial', 'residential', 'retail'],
-    'leisure': ['park', 'nature_reserve'],
-    'railway': ['rail', 'tram', 'station', 'stop'],
-    'surface': '',
-    'tracktype': '',
-    'tunnel': '',
-    'waterway': ['canal', 'drain', 'river', 'riverbank'],
-    'wood': 'deciduous'
-}
-
-NAME_TAGS_TO_KEEP_UNIVERSAL = {
-    'admin_level': '2',
-    'area': 'yes',
-    'mountain_pass': '',
-    'natural': '',
-    'place': ['city', 'hamlet', 'island', 'isolated_dwelling', 'islet', 'locality', 'suburb', 'town', 'village', 'country']
-}
