@@ -7,43 +7,17 @@ constants, functions and object for file-system operations
 import json
 import os
 from os.path import isfile, join
-import subprocess
 import sys
 import zipfile
 import logging
-from pathlib import Path
 import shutil
-
-# import custom python packages
 import requests
 
+# import custom python packages
+
 log = logging.getLogger('main-logger')
 
 
-def get_git_root():
-    """
-    get the root directory of the git repository
-    """
-    return subprocess.Popen(['git', 'rev-parse', '--show-toplevel'],
-                            stdout=subprocess.PIPE).communicate()[0].rstrip().decode('utf-8')
-
-
-# User
-USER_WAHOO_MC = os.path.join(str(Path.home()), 'wahooMapsCreatorData')
-USER_DL_DIR = os.path.join(USER_WAHOO_MC, '_download')
-USER_MAPS_DIR = os.path.join(USER_DL_DIR, 'maps')
-LAND_POLYGONS_PATH = os.path.join(
-    USER_DL_DIR, 'land-polygons-split-4326', 'land_polygons.shp')
-GEOFABRIK_PATH = os.path.join(USER_DL_DIR, 'geofabrik.json')
-USER_OUTPUT_DIR = os.path.join(USER_WAHOO_MC, '_tiles')
-
-# Python Package - wahooMapsCreator directory
-WAHOO_MC_DIR = os.path.dirname(__file__)
-RESOURCES_DIR = os.path.join(WAHOO_MC_DIR, 'resources')
-TOOLING_WIN_DIR = os.path.join(WAHOO_MC_DIR, 'tooling_win')
-ROOT_DIR = os.path.abspath(os.path.join(os.path.dirname(__file__), os.pardir))
-
-
 def unzip(source_filename, dest_dir):
     """
     unzip the given file into the given directory
@@ -69,37 +43,13 @@ def unzip(source_filename, dest_dir):
             zip_file.extract(member, path)
 
 
-def initialize_work_directories():
-    """
-    Initialize work directories
-    """
-
-    # USER_DIR = os.path.join(str(Path.home()), 'gitcommon')
-
-    os.makedirs(USER_WAHOO_MC, exist_ok=True)
-
-    os.makedirs(USER_DL_DIR, exist_ok=True)
-    os.makedirs(USER_MAPS_DIR, exist_ok=True)
-    os.makedirs(USER_OUTPUT_DIR, exist_ok=True)
-
-
-def move_old_content_into_new_dirs():
-    """
-    copy files from download- and output- directory of earlier version to the new folders
-    delete directory from earlier versions afterwards
-
-    having folder on the same level as the wahooMapsCreator was introduces in release v1.1.0 with PR #93.
-    This coding is only valid/needed when using the cloned version or .zip version.
-    If working with a installed version via PyPI, nothing will be done because folders to copy do not exist
-    """
-    move_content('wahooMapsCreator_download', USER_DL_DIR)
-    move_content('wahooMapsCreator_output', USER_OUTPUT_DIR)
-
-
 def move_content(src_folder_name, dst_path):
     """
     copy files from source directory of to destination directory
     delete source directory afterwards
+
+    similar function to copy_or_move_files_and_folder but without user-request when overwriting
+    and only support for directories
     """
     # build path to old folder on the same level as wahooMapsCreator
     par_dir = os.path.abspath(os.path.join(os.path.join(
@@ -123,14 +73,18 @@ def move_content(src_folder_name, dst_path):
         shutil.rmtree(source_dir)
 
 
-def create_empty_directories(tiles_from_json):
+def create_empty_directories(parent_dir, tiles_from_json, border_countries):
     """
-    create empty directory for the files
+    create empty directories for each tile and each country
     """
     for tile in tiles_from_json:
-        outdir = os.path.join(USER_OUTPUT_DIR, f'{tile["x"]}', f'{tile["y"]}')
-        if not os.path.isdir(outdir):
-            os.makedirs(outdir)
+        outdir = os.path.join(parent_dir,
+                              f'{tile["x"]}', f'{tile["y"]}')
+        os.makedirs(outdir, exist_ok=True)
+
+    for country in border_countries:
+        outdir = os.path.join(parent_dir, country)
+        os.makedirs(outdir, exist_ok=True)
 
 
 def read_json_file(json_file_path):
@@ -155,11 +109,37 @@ def read_json_file(json_file_path):
     return tiles_from_json
 
 
+def read_json_file_generic(json_file_path):
+    """
+    reads content of given .json file
+    """
+    with open(json_file_path, encoding="utf-8") as json_file:
+        json_content = json.load(json_file)
+        json_file.close()
+
+    return json_content
+
+
+def write_json_file_generic(json_file_path, json_content):
+    """
+    writes content to .json file
+    """
+    # Serializing json
+    json_content = json.dumps(json_content, indent=4)
+
+    # Writing to file
+    with open(json_file_path, "w", encoding="utf-8") as json_file:
+        json_file.write(json_content)
+        json_file.close()
+
+
 def download_url_to_file(url, map_file_path):
     """
     download the content of a ULR to file
     """
-    request_geofabrik = requests.get(url, allow_redirects=True, stream=True)
+    # set timeout to 30 minutes (per file)
+    request_geofabrik = requests.get(
+        url, allow_redirects=True, stream=True, timeout=1800)
     if request_geofabrik.status_code != 200:
         log.error('! failed download URL: %s', url)
         sys.exit()
@@ -209,3 +189,83 @@ def get_filenames_of_jsons_in_folder(folder):
             json_files.extend([filename])
 
     return json_files
+
+
+def delete_o5m_pbf_files_in_folder(folder):
+    """
+    delete .o5m and .pbf files of given folder
+    """
+    onlyfiles = [f for f in os.listdir(folder) if isfile(join(folder, f))]
+
+    for file in onlyfiles:
+        if file.endswith('.o5m') or file.endswith('.pbf'):
+            try:
+                os.remove(os.path.join(folder, file))
+            except OSError:
+                pass
+
+
+def copy_or_move_files_and_folder(from_path, to_path, delete_from_dir=False):
+    """
+    copy content from source directory to destination directory
+    optionally delete source directory afterwards
+
+    similar function to move_content but with user-request when overwriting and support for files
+    """
+    # check if from path/file exists at all
+    if os.path.exists(from_path):
+
+        # given path is a directory
+        if os.path.isdir(from_path):
+            # first create the to-directory if not already there
+            os.makedirs(to_path, exist_ok=True)
+
+            for item in os.listdir(from_path):
+                from_item = os.path.join(from_path, item)
+                to_item = os.path.join(to_path, item)
+
+                # copy directory
+                if os.path.isdir(from_item):
+                    copy_directory_w_user_input(from_item, to_item)
+
+                # copy file
+                else:
+                    copy_file_w_user_input(from_item, to_item)
+
+        # given path is a file
+        else:
+            copy_file_w_user_input(from_path, to_path)
+
+        # directory
+        if delete_from_dir:
+            shutil.rmtree(from_path)
+
+
+def copy_directory_w_user_input(from_item, to_item):
+    """
+    copy content from source directory to destination directory
+    """
+    if not os.path.isdir(to_item):
+        shutil.copytree(from_item, to_item)
+    else:
+        val = input(f"{to_item} exists already. Overwrite? (y/n):")
+        if val == 'y':
+            shutil.copytree(from_item, to_item)
+            log.info('! %s overwritten', to_item)
+        else:
+            log.debug('! %s not copied, exists already.', to_item)
+
+
+def copy_file_w_user_input(from_item, to_item):
+    """
+    copy source file to destination file
+    """
+    if not os.path.isfile(to_item):
+        shutil.copy2(from_item, to_item)
+    else:
+        val = input(f"{to_item} exists already. Overwrite? (y/n):")
+        if val == 'y':
+            shutil.copy2(from_item, to_item)
+            log.info('! %s overwritten', to_item)
+        else:
+            log.debug('! %s not copied, exists already.', to_item)
